@@ -8,7 +8,7 @@ use base qw(File::Monitor::Base);
 
 use File::Monitor::Object;
 
-use version; our $VERSION = qv('0.0.2');
+use version; our $VERSION = qv('0.0.3');
 
 sub _initialize {
     my $self = shift;
@@ -21,15 +21,10 @@ sub _initialize {
     $self->{_monitors} = { };
 }
 
-sub set_watcher {
+sub _set_watcher {
     my $self   = shift;
     my $object = shift;
 
-    my @need_method = grep { ! $object->can($_) } qw(name scan);
-    if (@need_method) {
-        croak "Watcher $object lacks the required methods: ", join(', ', @need_method);
-    }
-
     my $name = $object->name;
     
     return $self->{_monitors}->{$name} = $object;
@@ -38,7 +33,31 @@ sub set_watcher {
 sub watch {
     my $self = shift;
 
-    return $self->set_watcher( File::Monitor::Object->new( @_ ) );
+    my $args;
+
+    if (ref $_[0] eq 'HASH') {
+        # Hash ref containing all arguments
+        $args = shift;
+
+        croak "When options are supplied as a hash there may be no other arguments"
+            if @_;
+    } else {
+        # File/dir name, optional callback
+        my $name     = shift or croak "A filename must be specified";
+        my $callback = shift;
+
+        $args = {
+            name    => $name
+        };
+
+        # If a callback is defined install it for all changes
+        $args->{callback}->{change} = $callback
+            if defined $callback;
+    }
+
+    $args->{owner} = $self;
+
+    return $self->_set_watcher( File::Monitor::Object->new( $args ) );
 }
 
 sub unwatch {
@@ -73,7 +92,7 @@ File::Monitor - Monitor files and directories for changes.
 
 =head1 VERSION
 
-This document describes File::Monitor version 0.0.2
+This document describes File::Monitor version 0.0.3
 
 =head1 SYNOPSIS
 
@@ -220,9 +239,7 @@ You may register callbacks for a specific file or directory.
     } );
 
 This last example shows the canonical way of specifying the arguments to
-C<watch> as a hash reference. Any arguments passed to C<watch> are
-passed unchanged to C<< File::Monitor::Object->new >>; See
-L<File::Monitor::Object> for more information.
+C<watch> as a hash reference. See C<watch> for more details.
 
 =head2 Directories
 
@@ -258,22 +275,101 @@ present, must be a reference to a hash that maps event types to handler
 subroutines. See L<File::Monitor::Delta> for a full list of available
 event types.
 
-=item C<< set_watcher( $object ) >>
-
-Add a L<File::Monitor::Object> (or compatible object) to the list of
-objects monitored. Replaces any existing watcher object registered for
-the same file or directory.
-
-The object added must expose the methods C<scan> and C<name> with the same
-semantics as L<File::Monitor::Object>.
-
 =item C<< watch( $name, $callback | { args } ) >>
 
-Create a new L<File::Monitor::Object> and add it to this monitor. This
-call is a convenience shortcut for
+Create a new L<File::Monitor::Object> and add it to this monitor.
 
-    my $watcher = File::Monitor::Object->new( $args );
-    $monitor->set_watcher( $watcher );
+The passed hash reference contains various options as follows:
+
+    $monitor->watch( {
+        name        => $file_or_directory_name,
+        recurse     => $should_recurse_directory,
+        files       => $should_read_files_in_directory,
+        callback    => {
+            $some_event => sub {
+                # Handler for $some_event
+            },
+            $other_event => sub {
+                # Handler for $other_event
+            }
+        }
+    } );
+
+Here are those options in more detail:
+
+=over
+
+=item C<name>
+
+The name of the file or directory to be monitored. Relative paths will
+be made absolute relative to the current directory at the time of the
+call. This option is mandatory; C<new> will croak if it is missing.
+
+=item C<recurse>
+
+If this is a directory and C<recurse> is true monitor the entire
+directory tree below this directory.
+
+=item C<files>
+
+If this is a directory and C<files> is true monitor the files and
+directories immediately below this directory but don't recurse down the
+directory tree.
+
+Note that if you specify C<recurse> or C<files> only the I<names> of
+contained files will be monitored. Changes to the contents of contained
+files are not detected.
+
+=item C<callback>
+
+Provides a reference to a hash of callback handlers the keys of which
+are the names of events as described in L<File::Monitor::Delta>.
+
+=back
+
+Callback subroutines are called with the following arguments:
+
+=over
+
+=item C<$name>
+
+The name of the file or directory that has changed.
+
+=item C<$event>
+
+The type of change. If the callback was registered for a specific event
+it will be passed here. The actual event may be one of the events below
+the specified event in the event hierarchy. See L<File::Monitor::Delta>
+for more details.
+
+=item C<$delta>
+
+The L<File::Monitor::Delta> object that describes this change.
+
+=back
+
+As a convenience C<watch> may be called with a simpler form of arguments:
+
+    $monitor->watch( $name );
+
+is equivalent to
+
+    $monitor->watch( {
+        name    => $name
+    } );
+
+And
+
+    $monitor->watch( $name, $callback );
+
+is eqivalent to
+
+    $monitor->watch( {
+        name        => $name
+        callback    => {
+            change      => $callback
+        }
+    } );
 
 =item C<< unwatch( $name ) >>
 
@@ -344,15 +440,6 @@ The L<File::Monitor::Delta> object that describes this change.
 
 =over
 
-=item C<< Watcher %s lacks the required methods: %s >>
-
-You may pass any object to set_watcher that exposes methods called
-C<name> and C<scan>. The object you have passed doesn't support one or
-both of those methods.
-
-This is most likely because intended to pass an instance of
-L<File::Monitor::Object> but have actually passed something else.
-
 =item C<< A filename must be specified >>
 
 You must pass C<unwatch> the name of a file or directory to stop watching.
