@@ -4,13 +4,14 @@ use strict;
 use warnings;
 use Carp;
 use File::Spec;
+use Scalar::Util qw(weaken);
 use Fcntl ':mode';
 
 use File::Monitor::Delta;
 
 use base qw(File::Monitor::Base);
 
-use version; our $VERSION = qv('0.0.2');
+use version; our $VERSION = qv('0.0.3');
 
 my @STAT_FIELDS;
 my @INFO_FIELDS;
@@ -61,77 +62,29 @@ BEGIN {
     }
 }
 
-sub _guess_class {
-    return $CLASS if $CLASS;
-    
-    my %stand_in = (
-        'File::Monitor::Object::Linux'  => qr/linux/
-    );
-
-    # Class to bless our objects to
-    $CLASS = __PACKAGE__;
-
-    # Attempt to find a platform specific stand-in
-    SI: while ( my ($module, $check) = each %stand_in ) {
-        if ( $^O =~ $check ) {
-            eval "require $module";
-            next SI if $@;
-            if ( my $class = $module->_stand_in ) {
-                $CLASS = $class;
-                last SI;
-            }
-        }
-    }
-
-    return $CLASS;
-}
-
-sub new {
-    my $class = shift;
-    
-    $class = _guess_class();
-    my $self = bless { }, $class;
-    $self->_initialize(@_);
-
-    return $self;
-}
-
 sub _initialize {
     my $self = shift;
-    my $args;
+    my $args = shift;
 
     # Normalize the args
 
-    if (ref $_[0] eq 'HASH') {
-        # Hash ref containing all arguments
-        $args = shift;
-
-        croak "When options are supplied as a hash there may be no other arguments"
-            if @_;
-
-        croak "The name option must be supplied"
-            unless exists $args->{name};
-    } else {
-        # File/dir name, optional callback
-        my $name     = shift or croak "A filename must be specified";
-        my $callback = shift;
-
-        $args = {
-            name    => $name
-        };
-
-        # If a callback is defined install it for all changes
-        $args->{callback}->{change} = $callback
-            if defined $callback;
-    }
-
     $self->SUPER::_initialize( $args );
     $self->_install_callbacks( $args );
 
-    # Build our object
-    $self->{name}            = $self->_canonical_name( delete $args->{name} );
     $self->{_info}->{virgin} = 1;
 
+    my $name = delete $args->{name}
+        or croak "The name option must be supplied";
+
+    # Build our object
+    $self->{name} = $self->_canonical_name( $name );
+    
+    $self->{_owner} = delete $args->{owner} 
+        or croak "A " . __PACKAGE__ . " must have an owner";
+
+    # Avoid circular references
+    weaken $self->{_owner};
+
     for my $opt (qw(files recurse)) {
         $self->{_options}->{$opt} = delete $args->{$opt};
     }
@@ -227,28 +180,11 @@ File::Monitor::Object - Monitor a filesystem object for changes.
 
 =head1 VERSION
 
-This document describes File::Monitor::Object version 0.0.2
+This document describes File::Monitor::Object version 0.0.3
 
 =head1 SYNOPSIS
 
-May be used directly to monitor a single file or directory.
-
-    use File::Monitor::Object;
-
-    # Watch a file
-    $object = File::Monitor::Object->new( 'somefile.txt' );
-
-    # First call to scan just captures a snapshot of file/directory
-    # state; doesn't return any results
-    $object->scan;
-
-    # Later, check for any changes
-    if ( my $change = $object->scan ) {
-        # Object changed
-    }
-
-May also be used with L<File::Monitor> to monitor multiple files and
-directories.
+Created by L<File::Monitor> to monitor a single file or directory.
 
     use File::Monitor;
     use File::Monitor::Object;
@@ -256,24 +192,23 @@ directories.
     my $monitor = File::Monitor->new();
 
     for my $file ( @files ) {
-        my $object = File::Monitor::Object->new( $file );
-        $monitor->set_watcher( $object );
+        $monitor->watch( $file );
     }
 
     # First scan just finds out about the monitored files. No changes
     # will be reported.
-    $object->scan;
+    $monitor->scan;
 
     # Later perform a scan and gather any changes
-    for my $change ( $object->scan ) {
+    for my $change ( $monitor->scan ) {
         # $change is a File::Monitor::Delta
     }
 
 =head1 DESCRIPTION
 
-Monitors changes to a single file or directory. For many applications it
-may be more convenient to use the interface provided by L<File::Monitor>
-which allows multiple files and directories to be monitored.
+Monitors changes to a single file or directory. Don't create a
+C<File::Monitor::Object> directly; instead call C<watch> on
+L<File::Monitor>.
 
 A C<File::Monitor::Object> represents a single file or directory. The
 corresponding file or directory need not exist; a file being created is
@@ -327,98 +262,8 @@ scans I<will> take a long time.
 
 =item C<< new( $args ) >>
 
-Create a new C<File::Monitor::Object>. The passed hash reference
-contains various options as follows:
-
-    my $object = File::Monitor::Object->new( {
-        name        => $file_or_directory_name,
-        recurse     => $should_recurse_directory,
-        files       => $should_read_files_in_directory,
-        callback    => {
-            $some_event => sub {
-                # Handler for $some_event
-            },
-            $other_event => sub {
-                # Handler for $other_event
-            }
-        }
-    } );
-
-Here are those options in more detail:
-
-=over
-
-=item C<name>
-
-The name of the file or directory to be monitored. Relative paths will
-be made absolute relative to the current directory at the time of the
-call. This option is mandatory; C<new> will croak if it is missing.
-
-=item C<recurse>
-
-If this is a directory and C<recurse> is true monitor the entire
-directory tree below this directory.
-
-=item C<files>
-
-If this is a directory and C<files> is true monitor the files and
-directories immediately below this directory but don't recurse down the
-directory tree.
-
-Note that if you specify C<recurse> or C<files> only the I<names> of
-contained files will be monitored. Changes to the contents of contained
-files are not detected.
-
-=item C<callback>
-
-Provides a reference to a hash of callback handlers the keys of which
-are the names of events as described in L<File::Monitor::Delta>.
-
-=back
-
-Callback subroutines are called with the following arguments:
-
-=over
-
-=item C<$name>
-
-The name of the file or directory that has changed.
-
-=item C<$event>
-
-The type of change. If the callback was registered for a specific event
-it will be passed here. The actual event may be one of the events below
-the specified event in the event hierarchy. See L<File::Monitor::Delta>
-for more details.
-
-=item C<$delta>
-
-The L<File::Monitor::Delta> object that describes this change.
-
-=back
-
-As a convenience C<new> may be called with a simpler form of arguments:
-
-    my $obj = File::Monitor::Object->new( $name );
-
-is equivalent to
-
-    my $obj = File::Monitor::Object->new( {
-        name    => $name
-    } );
-
-And
-
-    my $obj = File::Monitor::Object->new( $name, $callback );
-
-is eqivalent to
-
-    my $obj = File::Monitor::Object->new( {
-        name        => $name
-        callback    => {
-            change      => $callback
-        }
-    } );
+Create a new C<File::Monitor::Object>. Don't call C<new> directly; use
+instead L<< File::Monitor->watch >>.
 
 =item C<< scan() >>
 
@@ -432,9 +277,6 @@ if no changes occurred.
         # changes to the monitored file or directory.
     }
 
-Any callbacks that are registered will have been triggered before
-C<scan> returns.
-
 When C<scan> is first called the current state of the monitored
 file/directory will be captured but no change will be reported.
 
